@@ -1,4 +1,4 @@
-__version__ = "0.1.2"
+__version__ = "0.2.0"
 
 
 from beet import Context
@@ -11,6 +11,6 @@ def beet_default(ctx: Context):
         load(
             data_pack={"data/reapermc/modules": "@reapermc/modules"},
         ),
-        bolt(entrypoint="*:main"),
+        bolt(entrypoint=["*:main", "reapermc:reaper_cleanup"]),
         "bolt_expressions.plugin",
     )
